@@ -123,9 +123,9 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
         """
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.resize(480, 430)
-            self.privateCheckBox.setGeometry(QRect(10, 260, 460, 70))
-            self.saveButton.setGeometry(QRect(10, 350, 460, 70))
+            self.resize(480, 410)
+            self.privateCheckBox.setGeometry(QRect(10, 250, 460, 70))
+            self.saveButton.setGeometry(QRect(10, 330, 460, 70))
         else:
             self.resize(800, 400)
             self.saveButton.setGeometry(QRect(640, 290, 150, 70))
@@ -735,6 +735,8 @@ class SwitchAccountDialog(QDialog, Ui_SwitchAccountDialog):
             item = QListWidgetItem(username)
             item.setTextAlignment(Qt.AlignCenter)
             self.listWidget.addItem(item)
+            if username == youtubeservice.YouTubeDataService.currentUser:
+                self.listWidget.setCurrentItem(item)
         self.show()
 
     @pyqtSignature("QListWidgetItem*")
@@ -931,8 +933,8 @@ class EditAccountDialog(QDialog, Ui_EditAccountDialog):
         if screenGeometry.height() > screenGeometry.width():
             self.resize(480, 610)
             self.defaultCheckBox.setGeometry(QRect(10, 370, 460, 70))
-            self.saveButton.setGeometry(QRect(10, 450, 460, 70))
-            self.editButton.setGeometry(QRect(10, 530, 460, 70))
+            self.saveButton.setGeometry(QRect(10, 530, 460, 70))
+            self.editButton.setGeometry(QRect(10, 450, 460, 70))
         else:
             self.resize(800, 380)
             self.defaultCheckBox.setGeometry(QRect(480, 50, 310, 70))
