@@ -373,7 +373,10 @@ class YouTubeVideoPlayer(QThread):
             os.system(playbackCommand % filename.encode("utf-8"))
         else:
             videoUrl = YouTubeDataService.getVideoUrl(self.video,  YouTubeVideoPlayer.playbackFormat)
-            os.system(playbackCommand % videoUrl)  
+            self.tempfile = "%s/%s.mp4.temp" % (YouTubeVideoDownloader.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
+            downloader = DownloadURLOpener()
+            downloader.retrieve_resume(videoUrl,  tempfile)
+            os.system(playbackCommand % self.tempfile)  
 
     def run(self):
         if self.video != None:
